@@ -21,15 +21,17 @@ def _set_output(groups, which):
     """
     Refactored subroutine used by ``hide`` and ``show``.
     """
-    # Preserve original values, pull in new given value to use
-    previous = {}
-    for group in output.expand_aliases(groups):
-        previous[group] = output[group]
-        output[group] = which
-    # Yield control
-    yield
-    # Restore original values
-    output.update(previous)
+    try:
+        # Preserve original values, pull in new given value to use
+        previous = {}
+        for group in output.expand_aliases(groups):
+            previous[group] = output[group]
+            output[group] = which
+        # Yield control
+        yield
+    finally:
+        # Restore original values
+        output.update(previous)
 
 
 @contextmanager
@@ -85,13 +87,19 @@ def _setenv(**kwargs):
     to be used directly.
     """
     previous = {}
+    new = []
     for key, value in kwargs.iteritems():
-        previous[key] = env[key]
+        if key in env:
+            previous[key] = env[key]
+        else:
+            new.append(key)
         env[key] = value
     try:
         yield
     finally:
         env.update(previous)
+        for key in new:
+            del env[key]
 
 
 def settings(*args, **kwargs):
@@ -142,12 +150,15 @@ def settings(*args, **kwargs):
 
 def cd(path):
     """
-    Context manager that keeps directory state when calling operations.
+    Context manager that keeps directory state when calling remote operations.
 
     Any calls to `run`, `sudo`, `get`, or `put` within the wrapped block will
     implicitly have a string similar to ``"cd <path> && "`` prefixed in order
-    to give the sense that there is actually statefulness involved.  `cd` only
-    affects the remote paths for `get` and `put` -- local paths are untouched.
+    to give the sense that there is actually statefulness involved.
+
+    .. note::
+        `cd` only affects *remote* paths -- to modify *local* paths, use
+        `~fabric.context_managers.lcd`.
 
     Because use of `cd` affects all such invocations, any code making use of
     those operations, such as much of the ``contrib`` section, will also be
@@ -194,6 +205,8 @@ def cd(path):
     .. versionchanged:: 1.0
         Applies to `get` and `put` in addition to the command-running
         operations.
+
+    .. seealso:: `~fabric.context_managers.lcd`
     """
     return _change_cwd('cwd', path)
 
