@@ -5,8 +5,8 @@ import copy
 import getpass
 import sys
 
-import paramiko
-from nose.tools import with_setup, raises, ok_
+import ssh
+from nose.tools import with_setup, ok_
 from fudge import (Fake, clear_calls, clear_expectations, patch_object, verify,
     with_patched_object, patched_context, with_fakes)
 
@@ -159,7 +159,7 @@ class TestNetwork(FabricTest):
     @server()
     def test_saved_authentication_returns_client_object(self):
         cache = HostConnectionCache()
-        assert isinstance(cache[env.host_string], paramiko.SSHClient)
+        assert isinstance(cache[env.host_string], ssh.SSHClient)
 
     @server()
     @with_fakes
@@ -170,8 +170,7 @@ class TestNetwork(FabricTest):
             cache[env.host_string]
 
 
-    @raises(SystemExit)
-    @with_patched_object(output, 'aborts', False)
+    @aborts
     def test_aborts_on_prompt_with_abort_on_prompt(self):
         """
         abort_on_prompt=True should abort when prompt() is used
@@ -181,8 +180,7 @@ class TestNetwork(FabricTest):
 
 
     @server()
-    @raises(SystemExit)
-    @with_patched_object(output, 'aborts', False)
+    @aborts
     def test_aborts_on_password_prompt_with_abort_on_prompt(self):
         """
         abort_on_prompt=True should abort when password prompts occur
@@ -282,7 +280,7 @@ class TestNetwork(FabricTest):
         output.everything = False
         with password_response(PASSWORDS[env.user], silent=False):
             run("ls /simple")
-        regex = r'^\[%s\] Login password: ' % env.host_string
+        regex = r'^\[%s\] Login password for \'%s\': ' % (env.host_string, env.user)
         assert_contains(regex, sys.stderr.getvalue())
 
     @mock_streams('stderr')
@@ -297,7 +295,7 @@ class TestNetwork(FabricTest):
         output.everything = False
         with password_response(CLIENT_PRIVKEY_PASSPHRASE, silent=False):
             run("ls /simple")
-        regex = r'^\[%s\] Login password: ' % env.host_string
+        regex = r'^\[%s\] Login password for \'%s\': ' % (env.host_string, env.user)
         assert_contains(regex, sys.stderr.getvalue())
 
     def test_sudo_prompt_display_passthrough(self):
@@ -328,20 +326,23 @@ class TestNetwork(FabricTest):
         if display_output:
             expected = """
 [%(prefix)s] sudo: oneliner
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 [%(prefix)s] out: sudo password:
 [%(prefix)s] out: Sorry, try again.
 [%(prefix)s] out: sudo password: 
 [%(prefix)s] out: result
-""" % {'prefix': env.host_string}
+""" % {'prefix': env.host_string, 'user': env.user}
         else:
             # Note lack of first sudo prompt (as it's autoresponded to) and of
             # course the actual result output.
             expected = """
 [%(prefix)s] sudo: oneliner
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 [%(prefix)s] out: Sorry, try again.
-[%(prefix)s] out: sudo password: """ % {'prefix': env.host_string}
+[%(prefix)s] out: sudo password: """ % {
+    'prefix': env.host_string,
+    'user': env.user
+}
         eq_(expected[1:], sys.stdall.getvalue())
 
     @mock_streams('both')
@@ -364,7 +365,7 @@ class TestNetwork(FabricTest):
             sudo('twoliner')
         expected = """
 [%(prefix)s] sudo: oneliner
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 [%(prefix)s] out: sudo password:
 [%(prefix)s] out: Sorry, try again.
 [%(prefix)s] out: sudo password: 
@@ -373,7 +374,7 @@ class TestNetwork(FabricTest):
 [%(prefix)s] out: sudo password:
 [%(prefix)s] out: result1
 [%(prefix)s] out: result2
-""" % {'prefix': env.host_string}
+""" % {'prefix': env.host_string, 'user': env.user}
         eq_(expected[1:], sys.stdall.getvalue())
 
     @mock_streams('both')
@@ -400,12 +401,12 @@ class TestNetwork(FabricTest):
                 run('silent')
         expected = """
 [%(prefix)s] run: normal
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 [%(prefix)s] out: foo
 [%(prefix)s] run: silent
 [%(prefix)s] run: normal
 [%(prefix)s] out: foo
-""" % {'prefix': env.host_string}
+""" % {'prefix': env.host_string, 'user': env.user}
         eq_(expected[1:], sys.stdall.getvalue())
 
     @mock_streams('both')
@@ -428,12 +429,12 @@ class TestNetwork(FabricTest):
             run('twoliner')
         expected = """
 [%(prefix)s] run: oneliner
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 [%(prefix)s] out: result
 [%(prefix)s] run: twoliner
 [%(prefix)s] out: result1
 [%(prefix)s] out: result2
-""" % {'prefix': env.host_string}
+""" % {'prefix': env.host_string, 'user': env.user}
         eq_(expected[1:], sys.stdall.getvalue())
 
     @mock_streams('both')
@@ -457,10 +458,10 @@ class TestNetwork(FabricTest):
                 run('twoliner')
         expected = """
 [%(prefix)s] run: oneliner
-[%(prefix)s] Login password: 
+[%(prefix)s] Login password for '%(user)s': 
 result
 [%(prefix)s] run: twoliner
 result1
 result2
-""" % {'prefix': env.host_string}
+""" % {'prefix': env.host_string, 'user': env.user}
         eq_(expected[1:], sys.stdall.getvalue())
